@@ -17,101 +17,10 @@ class Country:
         """ Setter for the name """
         self._name = value
 
-    name = property(_get_name, _set_name)
-
-
-class Airport:
-    def __init__(self):
-        """ Initiate the attributes """
-        self._name = None
-        self._city = None
-        self._country = None
-        self._iata = None
-        self._icao = None
-        self._latitude = None
-        self._longitude = None
-        self._altitude = None
-        self._timezone = None
-        self._dst = None
-        self._tz_database = None
-
-    def _get_name(self):
-        return self._name
-
-    def _set_name(self, value):
-        self._name = value
-
-    def _get_city(self):
-        return self._city
-
-    def _set_city(self, value):
-        self._city = value
-
-    def _get_country(self):
-        return self._country
-
-    def _set_country(self, value):
-        self._country = value
-
-    def _get_iata(self):
-        return self._iata
-
-    def _set_iata(self, value):
-        self._iata = value
-
-    def _get_icao(self):
-        return self._icao
-
-    def _set_icao(self, value):
-        self._icao = value
-
-    def _get_latitude(self):
-        return self._latitude
-
-    def _set_latitude(self, value):
-        self._latitude = value
-
-    def _get_longitude(self):
-        return self._longitude
-
-    def _set_longitude(self, value):
-        self._longitude = value
-
-    def _set_altitude(self, value):
-        self._altitude = value
-
-    def _get_altitude(self):
-        return self._altitude
-
-    def _get_timezone(self):
-        return self._timezone
-
-    def _set_timezone(self, value):
-        self._timezone = value
-
-    def _get_dst(self):
-        return self._dst
-
-    def _set_dst(self, value):
-        self._dst = value
-
-    def _get_tz_database(self):
-        return self._tz_database
-
-    def _set_tz_database(self, value):
-        self._tz_database = value
+    def __repr__(self):
+        return 'Country[name={name}]'.format(name=self.name)
 
     name = property(_get_name, _set_name)
-    city = property(_get_city, _set_city)
-    country = property(_get_country, _set_country)
-    iata = property(_get_iata, _set_iata)
-    icao = property(_get_icao, _set_icao)
-    latitude = property(_get_latitude, _set_latitude)
-    longitude = property(_get_longitude, _set_longitude)
-    altitude = property(_get_altitude, _set_altitude)
-    timezone = property(_get_timezone, _set_timezone)
-    dst = property(_get_dst, _set_dst)
-    tz_database = property(_get_tz_database, _set_tz_database)
 
 
 class Wind:
@@ -166,6 +75,14 @@ class Wind:
     def _set_unit(self, value):
         self._unit = value
 
+    def __repr__(self):
+        return """Wind[speed={speed}, direction={direction}, gust={gust}, degrees={degrees}
+        unit={unit}, min_variation={min_variation}, max_variation={max_variation}
+        ]
+        """.format(speed=self.speed, direction=self.direction,
+                   gust=self.gust, degrees=self.degrees, unit=self._unit,
+                   min_variation=self.min_variation, max_variation=self.max_variation)
+
     speed = property(_get_speed, _set_speed)
     direction = property(_get_direction, _set_direction)
     gust = property(_get_gust, _set_gust)
@@ -186,6 +103,9 @@ class WindShear(Wind):
     def _set_height(self, value):
         self._height = value
 
+    def __repr__(self):
+        return 'WindShear[height={height}'.format(height=self.height) + super().__repr__() + ']'
+
     height = property(_get_height, _set_height)
 
 
@@ -213,6 +133,12 @@ class Visibility:
     def _set_min_direction(self, value):
         self._min_direction = value
 
+    def __repr__(self):
+        return """Visibility[distance={distance}, min_distance={min_distance}
+        , min_direction={min_direction}]""".format(distance=self.distance,
+                                                   min_direction=self.min_direction,
+                                                   min_distance=self.min_distance)
+
     distance = property(_get_distance, _set_distance)
     min_distance = property(_get_min_distance, _set_min_distance)
     min_direction = property(_get_min_direction, _set_min_direction)
@@ -245,6 +171,13 @@ class WeatherCondition:
     def is_valid(self):
         return len(self._phenomenons) != 0 or self._descriptive == Descriptive.THUNDERSTORM
 
+    def __repr__(self):
+        return 'WeatherCondition[intensity={intensity}, descriptive={descriptive}, phenomenons={phenomenons}]'.format(
+            intensity=self.intensity,
+            descriptive=self.descriptive,
+            phenomenons=self.phenomenons
+        )
+
     intensity = property(_get_intensity, _set_intensity)
     descriptive = property(_get_descriptive, _set_descriptive)
     phenomenons = property(_get_phenomenons)
@@ -274,6 +207,13 @@ class TemperatureDated:
     def _set_hour(self, value):
         self._hour = value
 
+    def __repr__(self):
+        return 'TemperatureDated[temperature={temperature}, day={day}, hour={hour}]'.format(
+            temperature=self.temperature,
+            day=self.day,
+            hour=self.hour
+        )
+
     temperature = property(_get_temperature, _set_temperature)
     day = property(_get_day, _set_day)
     hour = property(_get_hour, _set_hour)
@@ -346,6 +286,23 @@ class RunwayInfo:
     def _set_braking_capacity(self, value):
         self._braking_capacity = value
 
+    def __repr__(self):
+        return """
+            RunwayInfo[name={name}, min_range={min_range}, max_range={max_range},
+            trend={trend}, indicator={indicator}, deposit_type={deposit_type},
+            coverage={coverage}, thickness={thickness}, braking_capacity={braking_capacity}]
+        """.format(
+            name=self.name,
+            min_range=self.min_range,
+            max_range=self.max_range,
+            trend=self.trend,
+            indicator=self.indicator,
+            deposit_type=self.deposit_type,
+            coverage=self.coverage,
+            thickness=self.thickness,
+            braking_capacity=self.braking_capacity
+        )
+
     name = property(_get_name, _set_name)
     min_range = property(_get_min_range, _set_min_range)
     max_range = property(_get_max_range, _set_max_range)
@@ -382,6 +339,13 @@ class Cloud:
     def _get_type(self):
         return self._type
 
+    def __repr__(self):
+        return 'Cloud[height={height}, quantity={quantity}, type={type}]'.format(
+            height=self.height,
+            quantity=self.quantity,
+            type=self.type
+        )
+
     height = property(_get_height, _set_height)
     quantity = property(_get_quantity, _set_quantity)
     type = property(_get_type, _set_type)
@@ -411,6 +375,13 @@ class Icing:
     def _set_depth(self, depth: int):
         self._depth = depth
 
+    def __repr__(self):
+        return 'Icing[intensity={intensity}, base_height={base_height}, depth={depth}]'.format(
+            intensity=self.intensity,
+            base_height=self.base_height,
+            depth=self.depth
+        )
+
     intensity = property(_get_intensity, _set_intensity)
     base_height = property(_get_base_height, _set_base_height)
     depth = property(_get_depth, _set_depth)
@@ -441,6 +412,13 @@ class Turbulence:
     def _set_depth(self, depth: int):
         self._depth = depth
 
+    def __repr__(self):
+        return 'Turbulence[intensity={intensity}, base_height={base_height}, depth={depth}]'.format(
+            intensity=self.intensity,
+            base_height=self.base_height,
+            depth=self.depth
+        )
+
     intensity = property(_get_intensity, _set_intensity)
     base_height = property(_get_base_height, _set_base_height)
     depth = property(_get_depth, _set_depth)
@@ -463,6 +441,12 @@ class ITafGroups:
     def add_icing(self, icing: Icing):
         self._icings.append(icing)
 
+    def __repr__(self):
+        return 'turbulence={turbulence}, icings={icings}'.format(
+            turbulence=self.turbulence,
+            icings=self.icings
+        )
+
     turbulence = property(_get_turbulence)
     icings = property(_get_icings)
 
@@ -537,6 +521,17 @@ class AbstractWeatherContainer(abc.ABC):
             self._weather_conditions.append(wc)
             return True
 
+    def __repr__(self):
+        return """
+        wind={wind}, visibility={visibility}, vertical_visibility={vertical_visibility},
+        wind_shear={wind_shear}, cavok={cavok}, remark={remark},
+        clouds={clouds}, weather_conditions={weather_conditions}
+        """.format(wind=self.wind, visibility=self.visibility,
+                   vertical_visibility=self.vertical_visibility,
+                   cavok=self.cavok, remark=self.remark,
+                   wind_shear=self.wind_shear,
+                   clouds=str(self.clouds), weather_conditions=self.weather_conditions)
+
     wind = property(_get_wind, _set_wind)
     visibility = property(_get_visibility, _set_visibility)
     vertical_visibility = property(_get_vertical_visibility, _set_vertical_visibility)
@@ -562,6 +557,9 @@ class AbstractValidity(abc.ABC):
     def _set_start_hour(self, value: int):
         self._start_hour = value
 
+    def __repr__(self):
+        return 'start_day={start_day}, start_hour={start_hour}'.format(start_day=self.start_day, start_hour=self.start_hour)
+
     start_day = property(_get_start_day, _set_start_day)
     start_hour = property(_get_start_hour, _set_start_hour)
 
@@ -572,7 +570,6 @@ class AbstractWeatherCode(AbstractWeatherContainer):
         super().__init__()
         self._day = None
         self._time = None
-        self._airport = None
         self._message = None
         self._station = None
         self._flags = set()
@@ -590,12 +587,6 @@ class AbstractWeatherCode(AbstractWeatherContainer):
     def _set_time(self, value: time):
         self._time = value
 
-    def _get_airport(self):
-        return self._airport
-
-    def _set_airport(self, value: Airport):
-        self._airport = value
-
     def _get_message(self):
         return self._message
 
@@ -632,9 +623,18 @@ class AbstractWeatherCode(AbstractWeatherContainer):
     def _is_nil(self):
         return Flag.NIL in self._flags
 
+    def __repr__(self):
+        return 'day={day}, time={time}, message={message}, station={station}, trends={trends}, flags={flags}, '.format(
+            day=self.day,
+            time=self.time,
+            message=self.message,
+            station=self.station,
+            trends=self.trends,
+            flags=self.flags
+        ) + super().__repr__()
+
     day = property(_get_day, _set_day)
     time = property(_get_time, _set_time)
-    airport = property(_get_airport, _set_airport)
     message = property(_get_message, _set_message)
     station = property(_get_station, _set_station)
     trends = property(_get_trends)
@@ -686,6 +686,15 @@ class Metar(AbstractWeatherCode):
     def add_runway_info(self, runway_info: RunwayInfo):
         self._runways_info.append(runway_info)
 
+    def __repr__(self):
+        return 'Metar[' + super().__repr__() + ', temperature={temperature}, dew_point={dew_point}, altimeter={altimeter}, nosig={nosig}, runways_info={runways_info}]'.format(
+            temperature=self.temperature,
+            dew_point=self.dew_point,
+            altimeter=self.altimeter,
+            nosig=self.nosig,
+            runways_info=self.runways_info,
+        )
+
     temperature = property(_get_temperature, _set_temperature)
     dew_point = property(_get_dew_point, _set_dew_point)
     altimeter = property(_get_altimeter, _set_altimeter)
@@ -735,6 +744,13 @@ class TAF(ITafGroups, AbstractWeatherCode):
     def fms(self):
         return list(filter(lambda trend: trend.type == WeatherChangeType.FM, self.trends))
 
+    def __repr__(self):
+        return 'TAF[' + AbstractWeatherCode.__repr__(self) + ITafGroups.__repr__(self) + ', validity={validity}, max_temperature={max_temperature}, min_temperature={min_temperature}]'.format(
+            validity=self.validity,
+            max_temperature=self.max_temperature,
+            min_temperature=self.min_temperature
+        )
+
     validity = property(_get_validity, _set_validity)
     max_temperature = property(_get_max_temperature, _set_max_temperature)
     min_temperature = property(_get_min_temperature, _set_min_temperature)
@@ -748,6 +764,9 @@ class AbstractTrend(AbstractWeatherContainer):
     def _get_type(self):
         return self._type
 
+    def __repr__(self):
+        return super().__repr__() + ', type={type}'.format(type=self.type)
+
     type = property(_get_type)
 
 
@@ -764,6 +783,9 @@ class MetarTrendTime:
     def _set_time(self, value: time):
         self._time = value
 
+    def __repr__(self):
+        return 'MetarTrendTime[type={type}, time={time}]'.format(type=self.type, time=self.time)
+
     type = property(_get_type)
     time = property(_get_time, _set_time)
 
@@ -780,6 +802,8 @@ class MetarTrend(AbstractTrend):
     def add_time(self, value: MetarTrendTime):
         self._times.append(value)
 
+    def __repr__(self):
+        return 'MetarTrend[' + super().__repr__() + ', times={times}'.format(times=self.times)
     times = property(_get_times)
 
 
@@ -801,6 +825,8 @@ class TAFTrend(AbstractTrend, ITafGroups):
     def _set_probability(self, prob: int):
         self._probability = prob
 
+    def __repr__(self):
+        return 'TAFTrend[' + ITafGroups.__repr__(self) + ', ' + AbstractTrend.__repr__(self) + ', validity={validity}, probability={probability}'.format(validity=self.validity, probability=self.probability)
     probability = property(_get_probability, _set_probability)
     validity = property(_get_validity, _set_validity)
 
@@ -823,6 +849,9 @@ class Validity(AbstractValidity):
     def _set_end_day(self, value: int):
         self._end_day = value
 
+    def __repr__(self):
+        return 'Validity[' + super().__repr__() + ', end_day={end_day}, end_hour={end_hour}]'.format(end_hour=self.end_hour, end_day=self.end_day)
+
     end_hour = property(_get_end_hour, _set_end_hour)
     end_day = property(_get_end_day, _set_end_day)
 
@@ -839,4 +868,7 @@ class FMValidity(AbstractValidity):
     def _set_start_minutes(self, value: int):
         self._start_minutes = value
 
+    def __repr__(self):
+        return 'FMValidity[' + super().__repr__() + ', strart_minutes={start_minutes}]'.format(start_minutes=self.start_minutes)
+
     start_minutes = property(_get_start_minutes, _set_start_minutes)
