@@ -99,7 +99,7 @@ class AbstractParser(abc.ABC):
     BECMG = 'BECMG'
     RMK = 'RMK'
     TOKENIZE_REGEX = r'\s((?=\d\/\dSM)(?<!\s\d\s)|(?!\d\/\dSM))|='
-    INTENSITY_REGEX = r'^(-|\+|VC)'
+    INTENSITY_REGEX = r'^(-|\+|VC|RE)'
     CAVOK = 'CAVOK'
 
     def __init__(self):
@@ -299,7 +299,7 @@ class TAFParser(AbstractParser):
         """
         single_line = taf_code.replace('\n', ' ')
         clean_line = re.sub(r'\s{2,}', ' ', single_line)
-        lines = re.sub(r'\s(PROB\d{2}\sTEMPO|TEMPO|INTER|BECMG|FM|PROB)', '\n\g<1>', clean_line).splitlines()
+        lines = re.sub(r'\s(PROB\d{2}\sTEMPO|TEMPO|INTER|BECMG|FM(?![A-Z]{2}\s)|PROB)', '\n\g<1>', clean_line).splitlines()
         lines_token = [self.tokenize(line) for line in lines]
 
         if len(lines_token) > 1:
